import request from '@/config/axios'

// 大模型问题模板 VO
export interface QuestionTemplateVO {
  id: string // id
  modelId: string // 模型id
  questionCode: string // 问题编号
  questionName: string // 问题名称
  questionContent: string // 问题内容
  dataLength: number // 输入个数
  isEnable: number // 是否启用（0禁用 1启用）
  remark: string // 备注
  createDate: Date // 创建时间
  updator: number // 更新者
  updateDate: Date // 更新时间
  settingList:[]//配置列表
}

// 大模型问题模板 API
export const QuestionTemplateApi = {
  // 查询大模型问题模板分页
  getQuestionTemplatePage: async (params: any) => {
    return await request.get({ url: `/ai/question-template/page`, params })
  },

  // 查询大模型问题模板详情
  getQuestionTemplate: async (id: number) => {
    return await request.get({ url: `/ai/question-template/get?id=` + id })
  },

  // 新增大模型问题模板
  createQuestionTemplate: async (data: QuestionTemplateVO) => {
    return await request.post({ url: `/ai/question-template/create`, data })
  },

  // 修改大模型问题模板
  updateQuestionTemplate: async (data: QuestionTemplateVO) => {
    return await request.put({ url: `/ai/question-template/update`, data })
  },

  // 删除大模型问题模板
  deleteQuestionTemplate: async (id: number) => {
    return await request.delete({ url: `/ai/question-template/delete?id=` + id })
  },

  // 导出大模型问题模板 Excel
  exportQuestionTemplate: async (params) => {
    return await request.download({ url: `/ai/question-template/export-excel`, params })
  },
}
